@@ -13,12 +13,14 @@ void create_about_box ( void ) {
 		gdk_window_show (about_dialog->window);
 		gdk_window_raise (about_dialog->window);
 	} else {
-	 	const gchar trans[] = N_("Untranslated Version");
+	 	const gchar *trans = _("Untranslated Version");
 		const gchar *authors[] = {
 			"Mike Newman <mikegtn@gnome.org>\n",
 			"with invaluable assistance from: \n",
 			"Jeff Waugh <jdub@perkypants.org>",
-			"Norihiro Umeda <Norihiro.Umeda@is.titech.ac.jp>",NULL};			pixbuf = gdk_pixbuf_new_from_file ( pic, NULL );
+			"Norihiro Umeda <Norihiro.Umeda@is.titech.ac.jp>",
+			NULL};
+			pixbuf = gdk_pixbuf_new_from_file ( pic, NULL );
 		about_dialog = gnome_about_new (
 			_("Desktop Library Version Inspector"),
 			VERSION, "© 2002-2003 Mike Newman",
@@ -31,4 +33,6 @@ void create_about_box ( void ) {
 		g_object_unref (G_OBJECT(pixbuf));
 		gtk_widget_show (about_dialog);
 	}
+	
+	g_free(pic);
 }
